@@ -45,6 +45,12 @@ unclass(Mefa(x1, samp[1:2,], join="inner"))
 ## creating new Mefa object without Mefa()
 new("Mefa", xtab=x1, samp=samp, taxa=taxa,join="left")
 
+## 0 and 1 row/col Mefa object
+x3[c(FALSE,FALSE,FALSE,FALSE),c(FALSE,FALSE,FALSE,FALSE)]
+x3[c(TRUE,FALSE,FALSE,FALSE),c(FALSE,FALSE,FALSE,FALSE)]
+x3[c(FALSE,FALSE,FALSE,FALSE),c(TRUE,FALSE,FALSE,FALSE)]
+x3[c(TRUE,FALSE,FALSE,FALSE),c(TRUE,FALSE,FALSE,FALSE)]
+
 ## Melt
 x0 <- Xtab(count ~ sample + species, x)
 x33 <- Xtab(count ~ sample + species + segment, x)
@@ -152,5 +158,17 @@ taxax <- NULL
 
 mbind(x,y)
 mbind(as(x,"sparseMatrix"),as(y,"sparseMatrix"))
-mbind(Mefa(x,sampx),Mefa(y,sampy,taxay))
+unclass(mbind(Mefa(x,sampx),Mefa(y,sampy,taxay)))
+
+## 1x1 cases
+unclass(Mefa(y,sampy,taxay)[1,1])
+unclass(Mefa(y,sampy[,1,drop=FALSE],taxay[,1,drop=FALSE]))
+unclass(Mefa(y,sampy[,1,drop=FALSE],taxay[,1,drop=FALSE])[1,1])
+
+z0 <- Mefa(y)
+samp(z0) <- sampy[,1,drop=FALSE]
+taxa(z0) <- taxay[,1,drop=FALSE]
+unclass(z0)
+xtab(z0) <- y[1,1,drop=FALSE]
+unclass(z0)
 
